/**
 * @license
 * Ajax Module for Yii2
 * Released under MIT license
 * Copyright Andrii Sorokin
 */

let yiiAjax = module.exports;

let forEach = require('lodash.foreach');
let isObject = require('lodash.isobject');

let status = function(response) {
  if (response.status >= 200 && response.status < 300) {
    return Promise.resolve(response);
  }
  return Promise.reject(new Error(response.statusText));
};

let json = function(response) {
  return response.json();
};

let extractData = function(data) {
  let result = '';
  if (isObject(data)) {
    forEach(data, function (value, key) {
      result += key + '=' + value + '&';
    });
  }
  return result;
};

let getCSRF = function(param, token) {
  let csrfParamMeta = document.getElementsByName(param)[0];
  let csrfTokenMeta = document.getElementsByName(token)[0];
  let csrfParam = csrfParamMeta ?
    document.getElementsByName(param)[0].getAttribute('content') : null;
  let csrfToken = csrfTokenMeta ?
    document.getElementsByName(token)[0].getAttribute('content') : null;
  return csrfParam + '=' + csrfToken;
};
yiiAjax.post = function (url, data) {

  let headers = {
    'Content-type': 'application/x-www-form-urlencoded; charset=UTF-8'
  };
  let token = getCSRF('csrf-param', 'csrf-token');
  let body = extractData(data) + token;
  let request = {
    method: 'post',
    headers: headers,
    credentials: 'include',
    body: body
  };
  return fetch(url, request)
    .then(status)
    .then(json);
};
